Skip to main content

BrIpInfo

GitHub tag (latest by date) Python GitHub

Uma maneira fácil de obter dados relativos a um IP/bloco CIDR associado a um fornecedor de serviço de internet (ISP).

Periodicamente, o Registro.br disponibiliza, via ftp, uma listagem (em um arquivo .txt) dos IPs/blocos CIDR ativos no Brasil, bem como a qual fornecedor de serviço de internet o mesmo é associado (juntamente com seu CNPJ).

A partir do desse arquivo, o BrIpInfo analisa e estrutura esses dados de uma forma amigável, permitindo a exportação do mesmo para os formatos json ou csv.

Features

  • Obtenção da listagem completa do IPs ativos no Brasil, e suas respectivas ISP's, com base no Registro.br;
  • Fácil atualização da listagem disponibilizada;
  • Exportação dos dados em um arquivo json ou csv.

Pré-Requisitos

Instalação & Configuração

Clonar repositório

Faça o clone do repositório da aplicação em um local de sua preferência.

git clone https://github.com/rogeriopaulos/BRIpinfo.git

Crie um ambiente virtual [OPCIONAL]

Embora não seja obrigatório, é recomendável a criação prévia de um ambiente virtual do python. Para maiores informações, veja esse passo-a-passo.

Instalando as dependências

No prompt de comando ou terminal do seu sistema operacional, acesse a pasta da aplicação e instale as dependências da mesma executando o comando abaixo.

Ps: Caso tenha criado um ambiente virtual antes, ative-o.

pip install -r requirements.txt

Setup da aplicação

Para finalizar, execute o setup da aplicação.

Importante: Para que o setup da aplicação ocorra normalmente, é necessário uma conexão de internet ativa.

Ps: Caso tenha criado um ambiente virtual antes, ative-o.

python bripinfo setup

Comandos & Uso

Geral

Usage: bripinfo [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  export  Export data from registro.br to json/csv.
  query   Query IP or CNPJ from Registro.br.
  setup   Load data from registro.br.

Exportação

Usage: bripinfo export [OPTIONS]

  Export data from registro.br to json/csv.

Options:
  -f, --format TEXT       Format: [json, csv]. Default: json.
  -d, --destination TEXT  Where to save. Default: "<current-dir>".

  -n, --name TEXT         Filename. Default: "nicbr-asn-blk-latest"
  --help                  Show this message and exit.

Consulta

Usage: bripinfo query [OPTIONS]

  Query IP or CNPJ from Registro.br.

Options:
  -t, --type TEXT    Type of query: [ip, cnpj]
  -s, --search TEXT  Term to searched (ip or cnpj). Ex: 192.168.0.22 (ip) |
                     10942479000139 (cnpj)

  --help             Show this message and exit.

Exemplos

python bripinfo export

...um arquivo no formato json será gerado no diretório corrente onde a aplicação foi baixada (git clone).

python bripinfo export -f csv -d /home -n "test"

...um arquivo no formato csv, com o nome "test", será gerado no diretório "/home".

python bripinfo query -t ip -s "186.241.20.224"

# output
{
    "cnpj": "33.000.118/0001-79",
    "ips": [
        "200.223.0.0/16",
        "200.199.0.0/17",
        (...)
    ],
    "name": "Telemar Norte Leste S.A.",
    "ref": "AS7738"
}

Versionamento

Este projeto segue as diretrizes do versionamento semântico (SemVer). Para maiores informações, acesse esse link.

Licença

Veja o arquivo LICENÇAS para saber os direitos e limitações da licença aplicada neste projeto (MIT).

Release files for bripinfo 2.0.1

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for bripinfo 2.0.1
File Size Uploaded
bripinfo-2.0.1.tar.gz 6.3 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for bripinfo 2.0.1
File Interpreter ABI Platform
bripinfo-2.0.1-py3-none-any.whl Python 3 none any Details

Total release size: 14.2 kB

Release files / bripinfo-2.0.1.tar.gz

Download URL bripinfo-2.0.1.tar.gz
Size 6.3 kB
Tags Source
SHA-256 checksum
How to use checksums
21d38a81c042bd70c6f1c182e9c480c83bcff8646ff49b58dae038e1c75df869
BLAKE2b-256 checksum
How to use checksums
61ad8140d73798d6947ef57ddef1d375c3c631f9d47e58de46507ae4609e6ca0
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.8.3 CPython/3.12.3 Linux/5.15.146.1-microsoft-standard-WSL2

Release files / bripinfo-2.0.1-py3-none-any.whl

Download URL bripinfo-2.0.1-py3-none-any.whl
Size 8.0 kB
Tags Python 3
SHA-256 checksum
How to use checksums
79f2963405f93fb66dff9765e1c6676e5a4435ea007d46b2336e7d97259a3fce
BLAKE2b-256 checksum
How to use checksums
8d360e784e31577221624620af9d00f60240efc5bc07cf3d74d4d7d9b5489b9c
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.8.3 CPython/3.12.3 Linux/5.15.146.1-microsoft-standard-WSL2

Release history Release notifications | RSS feed

This release

2.0.1 This release

2 release files

1.2.3

2 release files

1.2.2

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page